function Phi_S = HConduc(G, P, C, motif)
% Input:
% - G: the adjacency matrix of the given network.
% - P: the constructed transition tensor. 
% - C: the returned structure-rich graph cut. 
% - motif: the user-defined structures.
% Output:
% - Phi_S: the high-order conductance of the returned cluster regarding the user-defined structures. 


if strcmp(motif, 'Edge')
    d = sum(G,2);
    mu_V = sum(d);
    temp = sum(sum(G(C,C)));
    namta = full(sum(d(C)));
    if min(namta, mu_V - namta) == 0
        Phi_S = NaN; % the graph cut returned an empty set or the whole graph. 
    else
        Phi_S = (namta- temp)/ min(namta, mu_V - namta);
    end
end


if strcmp(motif, 'ThreeNodeLine') || strcmp(motif, 'Triangle')
    n = size(P,1);
    n_c = size(C,2);
    temp = zeros(1, n_c*n_c);
    for i = 1: n_c
        temp((i-1)*n_c+1:i*n_c) = (C(i)-1)*n + C;
    end
    Vol_S = nnz(P(C,:));
    numerator  = Vol_S - nnz(P(C, temp));
    denominator = min(Vol_S, nnz(P)-Vol_S);
    if denominator == 0
        Phi_S = NaN; % the graph cut returned an empty set or the whole graph. 
    else
        Phi_S = numerator / denominator;
    end
end